.deephaven-ipywidgets-widget {
  padding: 0;
  margin: 0;
}

.deephaven-ipywidgets-widget iframe {
  border: none;
  width: 100%;
}

/** 
 * ipywidgets has a white background for objects always, even on a dark theme. 
 * Set it to transparent so it looks better in dark themes (like VS Code) 
 */
.cell-output-ipywidget-background {
  background-color: transparent !important;
}
.jp-OutputArea-output {
  background-color: transparent;
}