#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Deephaven Data Labs LLC.
# Distributed under the terms of the Modified BSD License.

version_info = (0, 3, 1)
__version__ = ".".join(map(str, version_info))
